# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/nb_helpers/',
                'doc_host': 'https://wandb.github.io',
                'git_url': 'https://github.com/wandb/nb_helpers/tree/main/',
                'lib_path': 'nb_helpers'},
  'syms': { 'nb_helpers.actions': { 'nb_helpers.actions.create_comment_body': ('actions.html#create_comment_body', 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.create_issue_nb_fail': ( 'actions.html#create_issue_nb_fail',
                                                                                 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.download': ('actions.html#download', 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.download_payload': ('actions.html#download_payload', 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.get_api': ('actions.html#get_api', 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.get_colab_url2md': ('actions.html#get_colab_url2md', 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.open_zip': ('actions.html#open_zip', 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.post_colab_links': ('actions.html#post_colab_links', 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.update_comment': ('actions.html#update_comment', 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.upload_at': ('actions.html#upload_at', 'nb_helpers/actions.py'),
                                    'nb_helpers.actions.upload_modified_nbs': ( 'actions.html#upload_modified_nbs',
                                                                                'nb_helpers/actions.py')},
            'nb_helpers.clean': { 'nb_helpers.clean._create_table': ('clean.html#_create_table', 'nb_helpers/clean.py'),
                                  'nb_helpers.clean.clean_all': ('clean.html#clean_all', 'nb_helpers/clean.py'),
                                  'nb_helpers.clean.clean_cell': ('clean.html#clean_cell', 'nb_helpers/clean.py'),
                                  'nb_helpers.clean.clean_cell_output': ('clean.html#clean_cell_output', 'nb_helpers/clean.py'),
                                  'nb_helpers.clean.clean_nb': ('clean.html#clean_nb', 'nb_helpers/clean.py'),
                                  'nb_helpers.clean.clean_nbs': ('clean.html#clean_nbs', 'nb_helpers/clean.py'),
                                  'nb_helpers.clean.clean_one': ('clean.html#clean_one', 'nb_helpers/clean.py'),
                                  'nb_helpers.clean.clean_output_data_vnd': ('clean.html#clean_output_data_vnd', 'nb_helpers/clean.py'),
                                  'nb_helpers.clean.rm_execution_count': ('clean.html#rm_execution_count', 'nb_helpers/clean.py')},
            'nb_helpers.colab': { 'nb_helpers.colab._create_colab_cell': ('colab.html#_create_colab_cell', 'nb_helpers/colab.py'),
                                  'nb_helpers.colab.add_colab_badge': ('colab.html#add_colab_badge', 'nb_helpers/colab.py'),
                                  'nb_helpers.colab.add_colab_metadata': ('colab.html#add_colab_metadata', 'nb_helpers/colab.py'),
                                  'nb_helpers.colab.create_colab_badge_cell': ('colab.html#create_colab_badge_cell', 'nb_helpers/colab.py'),
                                  'nb_helpers.colab.get_colab_url': ('colab.html#get_colab_url', 'nb_helpers/colab.py'),
                                  'nb_helpers.colab.has_colab_badge': ('colab.html#has_colab_badge', 'nb_helpers/colab.py')},
            'nb_helpers.docker': {},
            'nb_helpers.export': { 'nb_helpers.export._export_code_cell': ('export.html#_export_code_cell', 'nb_helpers/export.py'),
                                   'nb_helpers.export._export_md_cell': ('export.html#_export_md_cell', 'nb_helpers/export.py'),
                                   'nb_helpers.export._export_one': ('export.html#_export_one', 'nb_helpers/export.py'),
                                   'nb_helpers.export.colab_url': ('export.html#colab_url', 'nb_helpers/export.py'),
                                   'nb_helpers.export.default_line_filter': ('export.html#default_line_filter', 'nb_helpers/export.py'),
                                   'nb_helpers.export.export': ('export.html#export', 'nb_helpers/export.py'),
                                   'nb_helpers.export.export_cell': ('export.html#export_cell', 'nb_helpers/export.py'),
                                   'nb_helpers.export.export_nbs': ('export.html#export_nbs', 'nb_helpers/export.py'),
                                   'nb_helpers.export.filter_out_lines': ('export.html#filter_out_lines', 'nb_helpers/export.py'),
                                   'nb_helpers.export.read_list_file': ('export.html#read_list_file', 'nb_helpers/export.py')},
            'nb_helpers.run': { 'nb_helpers.run.CaptureShell.prettytb': ('run.html#captureshell.prettytb', 'nb_helpers/run.py'),
                                'nb_helpers.run.exec_nb': ('run.html#exec_nb', 'nb_helpers/run.py'),
                                'nb_helpers.run.run_nbs': ('run.html#run_nbs', 'nb_helpers/run.py'),
                                'nb_helpers.run.run_one': ('run.html#run_one', 'nb_helpers/run.py'),
                                'nb_helpers.run.skip_nb': ('run.html#skip_nb', 'nb_helpers/run.py')},
            'nb_helpers.utils': { 'nb_helpers.utils.RichLogger': ('utils.html#richlogger', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.__init__': ('utils.html#richlogger.__init__', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger._format_colab_link': ( 'utils.html#richlogger._format_colab_link',
                                                                                      'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger._format_colab_link_md': ( 'utils.html#richlogger._format_colab_link_md',
                                                                                         'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.error': ('utils.html#richlogger.error', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.exception': ('utils.html#richlogger.exception', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.info': ('utils.html#richlogger.info', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.to_csv': ('utils.html#richlogger.to_csv', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.to_md': ('utils.html#richlogger.to_md', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.to_table': ('utils.html#richlogger.to_table', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.warning': ('utils.html#richlogger.warning', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.writerow': ('utils.html#richlogger.writerow', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.RichLogger.writerow_incolor': ( 'utils.html#richlogger.writerow_incolor',
                                                                                    'nb_helpers/utils.py'),
                                  'nb_helpers.utils._csv_to_md': ('utils.html#_csv_to_md', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils._format_row': ('utils.html#_format_row', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils._get_github_repo_remote': ('utils.html#_get_github_repo_remote', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.create_table': ('utils.html#create_table', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.csv_to_md': ('utils.html#csv_to_md', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.detect_imported_libs': ('utils.html#detect_imported_libs', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.extract_libs': ('utils.html#extract_libs', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.find_nbs': ('utils.html#find_nbs', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.get_repo': ('utils.html#get_repo', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.git_branches': ('utils.html#git_branches', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.git_current_branch': ('utils.html#git_current_branch', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.git_last_commit': ('utils.html#git_last_commit', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.git_local_repo': ('utils.html#git_local_repo', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.git_main_name': ('utils.html#git_main_name', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.git_origin_repo': ('utils.html#git_origin_repo', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.is_nb': ('utils.html#is_nb', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.print_output': ('utils.html#print_output', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.remove_rich_format': ('utils.html#remove_rich_format', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.search_cell': ('utils.html#search_cell', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.search_cells': ('utils.html#search_cells', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.search_string_in_nb': ('utils.html#search_string_in_nb', 'nb_helpers/utils.py'),
                                  'nb_helpers.utils.today': ('utils.html#today', 'nb_helpers/utils.py')},
            'nb_helpers.wandb': { 'nb_helpers.wandb.filter_nbs': ('wandb.html#filter_nbs', 'nb_helpers/wandb.py'),
                                  'nb_helpers.wandb.fix_nbs': ('wandb.html#fix_nbs', 'nb_helpers/wandb.py'),
                                  'nb_helpers.wandb.get_wandb_tracker': ('wandb.html#get_wandb_tracker', 'nb_helpers/wandb.py'),
                                  'nb_helpers.wandb.search_code': ('wandb.html#search_code', 'nb_helpers/wandb.py'),
                                  'nb_helpers.wandb.summary_nbs': ('wandb.html#summary_nbs', 'nb_helpers/wandb.py')}}}
